@@ -6,7 +6,7 @@ use warnings;
 
 package Log::Log4perl::Appender::RabbitMQ;
 BEGIN {
-  $Log::Log4perl::Appender::RabbitMQ::VERSION = '0.102030';
+  $Log::Log4perl::Appender::RabbitMQ::VERSION = '0.102220';
 }
 
 our @ISA = qw/ Log::Log4perl::Appender /;
@@ -81,7 +81,7 @@ sub new {
 
     # Create a new connection
     eval {
-        @{$self}{qw(mq channel)} = _connect_cached($self->{host}, \%connect_options);
+        $self->{mq} = _connect_cached($self->{host}, \%connect_options);
 
         # declare the exchange if declare_exchange is set
         $self->{mq}->exchange_declare(
@@ -113,8 +113,9 @@ sub new {
         my $host = shift;
         my $connect_options = shift;
 
+        # Create a cache key from the connection options and the host
         no warnings 'uninitialized';
-        my $cache_key = join(':', $host, map { $_ , $connect_options->{$_} } sort keys %$connect_options);
+        my $cache_key = join(':', $host, sort %$connect_options);
         use warnings;
 
         return $connection_cache{$cache_key} if $connection_cache{$cache_key};
@@ -177,7 +178,7 @@ Log::Log4perl::Appender::RabbitMQ - Log to RabbitMQ
 
 =head1 VERSION
 
-version 0.102030
+version 0.102220
 
 =head1 SYNOPSIS
 
